@@ -1,3 +1,7 @@
+from typing import Any
+from codepack.code import Code
+
+
 def add2(a, b):
     """exec a + b = ?"""
     print('exec add2')
@@ -48,3 +52,23 @@ def hello(name):
     ret = 'Hello, %s!' % name
     print(ret)
     return ret
+
+
+def dummy_callback1(x):
+    pass
+
+
+def dummy_callback2(x1, x2):
+    pass
+
+
+def dummy_callback3(x):
+    pass
+
+
+def dummy_function1(a: dict, b: str = 2, *args: 'Code', c: Any, d=3) -> int:
+    return 1
+
+
+def dummy_function2(a: dict, b: str = 2, *args: 'Code', c: Any, d=3, **kwargs: list) -> None:
+    return None
